@@ -2,7 +2,6 @@ import logging
 import os
 import sys
 
-
 # Get the path of the current file
 current_file_path = os.path.abspath(__file__)
 
@@ -11,7 +10,6 @@ parent_dir_path = os.path.dirname(os.path.dirname(current_file_path))
 
 sys.path.append(parent_dir_path)
 
-import graylog
 from graylog import GELFUDPHandler
 
 
@@ -19,7 +17,7 @@ def test():
     logger = logging.getLogger('test_logger')
     logger.setLevel(logging.DEBUG)
 
-    handler = GELFUDPHandler('82.157.73.141', 12202)
+    handler = GELFUDPHandler('82.157.73.141', 12202, facility='python-graylog')
     # handler = graylog.http.GELFHTTPHandler('log.kxxxl.com', 80)
     logger.addHandler(handler)
 
@@ -28,6 +26,8 @@ def test():
         'baz': 'qux',
     }
 
+    logger = logging.LoggerAdapter(logger, {'appid': 'os.getenv("GRAYLOG_FACILITY")'})
+
     logger.debug(f'''This is a multiline message. {handler}''', extra=details)
 
     print('Done.')
